@@ -113,7 +113,7 @@ class CamundaEngineClient:
             params=params.model_dump(
                 mode="json",
                 by_alias=True,
-                exclude_none=True,
+                exclude_unset=True,
             ),
         )
         raise_for_status(response)
@@ -143,11 +143,19 @@ class CamundaEngineClient:
         response = await self._http_client.post(
             self._urls.task,
             params=pagination_params,
-            content=schema.model_dump_json(by_alias=True, exclude_none=True),
+            content=schema.model_dump_json(by_alias=True, exclude_unset=True),
         )
         raise_for_status(response)
         return TASK_ADAPTER.validate_python(response.json())
 
+    async def update_task(self, task_id: UUID, *, schema: TaskSchema) -> None:
+        """Updates a task"""
+        response = await self._http_client.put(
+            self._urls.task_by_id(task_id),
+            content=schema.model_dump_json(by_alias=True),
+        )
+        raise_for_status(response)
+
     async def get_tasks_count(
         self,
         schema: GetTasksFilterSchema | None = None,
@@ -159,7 +167,7 @@ class CamundaEngineClient:
         schema = schema or GetTasksFilterSchema()
         response = await self._http_client.post(
             self._urls.tasks_count,
-            content=schema.model_dump_json(by_alias=True, exclude_none=True),
+            content=schema.model_dump_json(by_alias=True, exclude_unset=True),
         )
         raise_for_status(response)
         return CountSchema.model_validate(response.json())
@@ -170,7 +178,7 @@ class CamundaEngineClient:
     ) -> TaskSchema | None:
         """Retrieves a task by id"""
 
-        url = self._urls.get_task_by_id(str(ident))
+        url = self._urls.task_by_id(str(ident))
         response = await self._http_client.get(url)
 
         if response.status_code == HTTPStatus.NOT_FOUND:
@@ -213,6 +221,21 @@ class CamundaEngineClient:
         raise_for_status(response)
         return HISTORIC_PROCESS_INSTANCE_ADAPTER.validate_python(response.json())
 
+    async def get_history_process_instance(
+        self,
+        process_instance_id: UUID,
+    ) -> HistoricProcessInstanceSchema | None:
+        """Retrieves a historic process instance by id, according to the HistoricProcessInstance interface in the engine."""
+
+        response = await self._http_client.get(
+            self._urls.get_history_process_instance(process_instance_id),
+        )
+        if response.status_code == HTTPStatus.NOT_FOUND:
+            return None
+
+        raise_for_status(response)
+        return HistoricProcessInstanceSchema.model_validate(response.json())
+
     @deprecated(
         "Use `get_history_variable_instances` or `get_history_variable_instances_post` instead of this method. Will be removed later.",
     )
@@ -291,7 +314,7 @@ class CamundaEngineClient:
 
         response = await self._http_client.post(
             self._urls.update_process_instance_variables(str(process_instance_id)),
-            content=schema.model_dump_json(by_alias=True, exclude_none=True),
+            content=schema.model_dump_json(by_alias=True, exclude_unset=True),
         )
         raise_for_status(response)
 
@@ -370,7 +393,7 @@ class CamundaEngineClient:
         """
         response = await self._http_client.post(
             self._urls.message_send,
-            content=schema.model_dump_json(by_alias=True, exclude_none=True),
+            content=schema.model_dump_json(by_alias=True, exclude_unset=True),
         )
         raise_for_status(response)
 
