@@ -1,8 +1,8 @@
-from datetime import datetime
 from typing import Literal
 from uuid import UUID
 
 
+from camunda_client.clients.types_ import SerializedDateTime
 from camunda_client.types_ import (
     BaseSchema,
     MayBeNullableList,
@@ -41,9 +41,9 @@ class HistoricProcessInstanceSchema(BaseSchema):
     process_definition_version: int | None = None
     process_definition_id: str | None = None
     business_key: str | None = None
-    start_time: datetime | None = None
-    end_time: datetime | None = None
-    removal_time: datetime | None = None
+    start_time: SerializedDateTime | None = None
+    end_time: SerializedDateTime | None = None
+    removal_time: SerializedDateTime | None = None
     duration_in_millis: int | None = None
     start_user_id: str | None = None
     start_activity_id: str | None = None
@@ -75,9 +75,9 @@ class TaskSchema(BaseSchema):
     name: str
     assignee: str | None = None
     owner: str | None = None
-    created: datetime
-    due: datetime | None = None
-    last_updated: datetime | None = None
+    created: SerializedDateTime
+    due: SerializedDateTime | None = None
+    last_updated: SerializedDateTime | None = None
     delegation_state: DelegationState | None = None
     description: str | None = None
     execution_id: UUID
@@ -113,16 +113,16 @@ class HistoricTaskInstanceSchema(BaseSchema):
     delete_reason: str | None = None
     owner: str | None = None
     assignee: str | None = None
-    start_time: datetime
-    end_time: datetime | None = None
+    start_time: SerializedDateTime
+    end_time: SerializedDateTime | None = None
     duration: int | None = None
     task_definition_key: str
     priority: int | None = None
-    due: datetime | None = None
+    due: SerializedDateTime | None = None
     parent_task_id: str | None = None
-    follow_up: datetime | None = None
+    follow_up: SerializedDateTime | None = None
     tenant_id: str | None = None
-    removal_time: datetime | None = None
+    removal_time: SerializedDateTime | None = None
     root_process_instance_id: UUID | None = None
 
     @property
